# Generated by Django 2.2.28 on 2023-03-01 12:18

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Component',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('is_backlink', models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink')),
                ('allow_create_backlink', models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save')),
                ('name', models.CharField(blank=True, help_text='Component tag', max_length=255, null=True)),
                ('short_description', models.CharField(blank=True, max_length=255, null=True)),
                ('slug', models.SlugField(blank=True, null=True, unique=True)),
                ('creator', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='components', to=settings.AUTH_USER_MODEL)),
                ('preferred_route', models.CharField(blank=True, default='false', max_length=255, null=True)),
                ('auto_import', models.BooleanField(default=False, help_text='Enable the experimental routing functionnality, does not require script declaration.')),
                ('friendly_name', models.CharField(blank=True, max_length=255, null=True)),
            ],
            options={
                'verbose_name': 'component',
                'verbose_name_plural': 'components',
                'ordering': ['slug'],
                'abstract': False,
                'default_permissions': ['add', 'change', 'delete', 'view', 'control'],
                'lookup_field': 'slug',
                'rdf_type': 'sib:Component',
                'rdf_context': {'creator': 'foaf:user', 'name': 'sib:ComponentName', 'short_description': 'sib:ComponentShortDescription'},
                'auto_author': 'creator',
                'owner_field': 'creator',
                'container_path': '/components/',
                'serializer_fields': ['@id', 'name', 'short_description', 'creator', 'parameters'],
                'nested_fields': ['parameters'],
                'depth': 1,
                'anonymous_perms': ['view'],
                'authenticated_perms': ['inherit', 'add'],
                'owner_perms': ['inherit', 'change', 'delete'],
                'superuser_perms': ['view'],
            },
        ),
        migrations.CreateModel(
            name='Package',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('is_backlink', models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink')),
                ('allow_create_backlink', models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save')),
                ('friendly_name', models.CharField(blank=True, max_length=255, null=True)),
                ('short_description', models.CharField(blank=True, max_length=255, null=True)),
                ('distribution', models.CharField(blank=True, max_length=255, null=True)),
                ('module', models.CharField(blank=True, max_length=255, null=True)),
                ('slug', models.SlugField(blank=True, null=True, unique=True)),
                ('creator', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='packages', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'package',
                'verbose_name_plural': 'packages',
                'ordering': ['slug'],
                'abstract': False,
                'default_permissions': ['add', 'change', 'delete', 'view', 'control'],
                'lookup_field': 'slug',
                'rdf_type': 'sib:Package',
                'rdf_context': {'creator': 'foaf:user', 'name': 'sib:PackageName', 'short_description': 'sib:PackageShortDescription'},
                'auto_author': 'creator',
                'owner_field': 'creator',
                'container_path': '/packages/',
                'serializer_fields': ['@id', 'name', 'short_description', 'creator', 'distribution', 'module', 'parameters'],
                'nested_fields': ['parameters'],
                'depth': 1,
                'anonymous_perms': ['view'],
                'authenticated_perms': ['inherit', 'add'],
                'owner_perms': ['inherit', 'change', 'delete'],
                'superuser_perms': ['view'],
            },
        ),
        migrations.CreateModel(
            name='Parameter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('is_backlink', models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink')),
                ('allow_create_backlink', models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save')),
                ('friendly_name', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('key', models.CharField(blank=True, max_length=255, null=True)),
                ('default', models.CharField(blank=True, max_length=255, null=True)),
                ('component', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='parameters', to='djangoldp_component.Component')),
            ],
            options={
                'verbose_name': 'parameter',
                'verbose_name_plural': 'parameters',
                'abstract': False,
                'default_permissions': ['add', 'change', 'delete', 'view', 'control'],
                'rdf_type': 'sib:Parameter',
                'rdf_context': {'component': 'sib:Component', 'default': 'sib:ParameterDefaultValue', 'description': 'sib:ParameterDescription', 'key': 'sib:ParameterKey', 'name': 'sib:ParameterName', 'type': 'sib:ParameterType'},
                'owner_field': 'component.creator',
                'container_path': 'parameters/',
                'serializer_fields': ['@id', 'name', 'description', 'key', 'type', 'default'],
                'depth': 0,
                'anonymous_perms': ['view'],
                'authenticated_perms': ['inherit'],
                'owner_perms': ['inherit', 'change', 'delete'],
                'superuser_perms': ['inherit'],
            },
        ),
        migrations.CreateModel(
            name='ServerParameter',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('is_backlink', models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink')),
                ('allow_create_backlink', models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save')),
                ('friendly_name', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.CharField(blank=True, max_length=255, null=True)),
                ('key', models.CharField(blank=True, max_length=255, null=True)),
                ('default', models.CharField(blank=True, max_length=255, null=True)),
                ('package', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='parameters', to='djangoldp_component.Package')),
            ],
            options={
                'verbose_name': 'server parameter',
                'verbose_name_plural': 'server parameters',
                'abstract': False,
                'default_permissions': ['add', 'change', 'delete', 'view', 'control'],
                'rdf_type': 'sib:Parameter',
                'rdf_context': {'default': 'sib:ParameterDefaultValue', 'description': 'sib:ParameterDescription', 'key': 'sib:ParameterKey', 'name': 'sib:ParameterName', 'package': 'sib:Package'},
                'owner_field': 'package',
                'container_path': 'server-parameters/',
                'serializer_fields': ['@id', 'name', 'description', 'key', 'default'],
                'depth': 0,
                'anonymous_perms': ['view'],
                'authenticated_perms': ['inherit'],
                'owner_perms': ['inherit', 'change', 'delete'],
                'superuser_perms': ['inherit'],
            },
        ),
        migrations.CreateModel(
            name='Dependency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('is_backlink', models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink')),
                ('allow_create_backlink', models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save')),
                ('component', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='dependencies', to='djangoldp_component.Component')),
                ('package', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='dependencies', to='djangoldp_component.Package')),
            ],
            options={
                'verbose_name': 'dependency',
                'verbose_name_plural': 'dependencies',
                'abstract': False,
                'default_permissions': ['add', 'change', 'delete', 'view', 'control'],
                'rdf_type': 'sib:dependency',
                'rdf_context': {'component': 'sib:component', 'package': 'sib:package'},
                'container_path': 'dependencies/',
                'serializer_fields': ['@id', 'component', 'package'],
                'depth': 0,
                'anonymous_perms': ['view'],
                'authenticated_perms': ['inherit'],
                'superuser_perms': ['inherit'],
            },
        ),
        migrations.CreateModel(
            name='ComponentScriptTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('is_backlink', models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink')),
                ('allow_create_backlink', models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save')),
                ('friendly_name', models.CharField(blank=True, max_length=255, null=True)),
                ('src', models.URLField(blank=True, max_length=255, null=True)),
                ('integrity', models.CharField(blank=True, max_length=255, null=True)),
                ('component', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='script_tags', to='djangoldp_component.Component')),
            ],
            options={
                'verbose_name': 'script tag',
                'verbose_name_plural': 'script tags',
                'abstract': False,
                'default_permissions': ['add', 'change', 'delete', 'view', 'control'],
                'rdf_type': 'sib:scriptTag',
                'rdf_context': {'component': 'sib:component', 'friendly_name': 'sib:friendlyName', 'integrity': 'sib:componentScriptTagIntegrity', 'src': 'sib:componentScriptTagSrc'},
                'owner_field': 'component',
                'container_path': 'script-tags/',
                'serializer_fields': ['@id', 'friendly_name', 'src', 'integrity'],
                'depth': 0,
                'anonymous_perms': ['view'],
                'authenticated_perms': ['inherit'],
                'owner_perms': ['inherit', 'change', 'delete'],
                'superuser_perms': ['inherit'],
            },
        ),
    ]



from django.contrib import admin
from djangoldp.admin import DjangoLDPAdmin

from .models import Component, ComponentScriptTag, Package, Parameter, ServerParameter


class EmptyAdmin(admin.ModelAdmin):
    def get_model_perms(self, request):
        return {}


class ParameterInline(admin.TabularInline):
    model = Parameter
    exclude = ("urlid", "is_backlink", "allow_create_backlink")
    extra = 0


class ComponentScriptTagInline(admin.TabularInline):
    model = ComponentScriptTag
    exclude = ("urlid", "is_backlink", "allow_create_backlink")
    extra = 0


class ServerParameterInline(admin.TabularInline):
    model = ServerParameter
    exclude = ("urlid", "is_backlink", "allow_create_backlink")
    extra = 0


class ComponentAdmin(DjangoLDPAdmin):
    list_display = ("urlid", "friendly_name", "short_description")
    exclude = ("urlid", "slug", "is_backlink", "allow_create_backlink")
    inlines = [ComponentScriptTagInline, ParameterInline]
    search_fields = ["urlid", "friendly_name", "name", "parameters__parameter__name"]
    ordering = ["urlid"]


class PackageAdmin(DjangoLDPAdmin):
    list_display = ("urlid", "friendly_name", "short_description")
    exclude = ("urlid", "slug", "is_backlink", "allow_create_backlink")
    inlines = [ServerParameterInline]
    search_fields = ["urlid", "friendly_name", "parameters__parameter__name"]
    ordering = ["urlid"]


admin.site.register(Component, ComponentAdmin)
admin.site.register(Parameter, EmptyAdmin)
admin.site.register(ComponentScriptTag, EmptyAdmin)
admin.site.register(ServerParameter, EmptyAdmin)
admin.site.register(Package, PackageAdmin)



# Generated by Django 2.2.28 on 2023-03-28 15:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_component', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Dependency',
        ),
    ]



import uuid

from django.conf import settings
from django.contrib.auth import get_user_model
from django.db import models
from django.db.models.signals import pre_save
from django.dispatch import receiver
from django.utils.text import slugify
from django.utils.translation import ugettext_lazy as _
from djangoldp.models import Model
from rest_framework.exceptions import ValidationError


class Component(Model):
    friendly_name = models.CharField(max_length=255, blank=True, null=True)
    name = models.CharField(
        max_length=255, blank=True, null=True, help_text="Component tag"
    )
    short_description = models.CharField(max_length=255, blank=True, null=True)
    creator = models.ForeignKey(
        get_user_model(),
        related_name="components",
        on_delete=models.SET_NULL,
        null=True,
        blank=True,
    )
    preferred_route = models.CharField(
        max_length=255, blank=True, null=True, default="false"
    )
    auto_import = models.BooleanField(
        default=False,
        help_text="Enable the experimental routing functionnality, does not require script declaration.",
    )
    auto_menu = models.BooleanField(
        default=False,
        help_text="Enable the experimental menu functionnality, require a solid-***-menu component.",
    )
    slug = models.SlugField(unique=True, blank=True, null=True)

    def __str__(self):
        try:
            return "{} ({})".format(self.friendly_name, self.urlid)
        except:
            return self.urlid

    class Meta(Model.Meta):
        anonymous_perms = ["view"]
        authenticated_perms = ["inherit", "add"]
        auto_author = "creator"
        container_path = "/components/"
        depth = 1  # Do not serialize user
        lookup_field = "slug"
        nested_fields = ["parameters", "script_tags"]
        ordering = ["slug"]
        owner_field = "creator"
        owner_perms = ["inherit", "change", "delete"]
        # rdf_context = {
        #     "friendly_name": "sib:friendlyName",
        #     "name": "sib:tag",
        #     "short_description": "sib:shortDescription",
        #     "preferred_route": "sib:route",
        #     "auto_import": "sib:componentAutoImport",
        #     "auto_menu": "sib:componentAutoMenu",
        #     "creator": "foaf:user",
        #     "parameters": "ldp:Container",
        #     "script_tags": "ldp:Container",
        # }
        rdf_type = "sib:component"
        serializer_fields = [
            "@id",
            "friendly_name",
            "name",
            "short_description",
            "preferred_route",
            "auto_import",
            "auto_menu",
            "creator",
            "parameters",
            "script_tags",
        ]
        superuser_perms = ["view"]
        verbose_name = _("component")
        verbose_name_plural = _("components")


class ComponentScriptTag(Model):
    component = models.ForeignKey(
        Component,
        on_delete=models.CASCADE,
        related_name="script_tags",
        null=True,
        blank=True,
    )
    friendly_name = models.CharField(max_length=255, blank=True, null=True)
    src = models.URLField(max_length=255, blank=True, null=True)
    integrity = models.CharField(max_length=255, blank=True, null=True)

    def __str__(self):
        try:
            return "{} ({})".format(self.component.friendly_name, self.urlid)
        except:
            return self.urlid

    class Meta(Model.Meta):
        anonymous_perms = ["view"]
        authenticated_perms = ["inherit"]
        container_path = "script-tags/"
        owner_field = "component__creator"
        owner_perms = ["inherit", "change", "delete"]
        # rdf_context = {
        #     "component": "sib:component",
        #     "friendly_name": "sib:friendlyName",
        #     "src": "sib:componentScriptTagSrc",
        #     "integrity": "sib:componentScriptTagIntegrity",
        # }
        rdf_type = "sib:scriptTag"
        serializer_fields = ["@id", "friendly_name", "src", "integrity"]
        superuser_perms = ["inherit"]
        verbose_name = _("script tag")
        verbose_name_plural = _("script tags")


class Parameter(Model):
    component = models.ForeignKey(
        Component,
        on_delete=models.CASCADE,
        related_name="parameters",
        null=True,
        blank=True,
    )
    friendly_name = models.CharField(max_length=255, blank=True, null=True)
    description = models.CharField(max_length=255, blank=True, null=True)
    key = models.CharField(max_length=255, blank=True, null=True)
    default = models.CharField(max_length=255, blank=True, null=True)

    def __str__(self):
        try:
            return "{} -> {} ({})".format(
                self.component.friendly_name, self.friendly_name, self.urlid
            )
        except:
            return self.urlid

    class Meta(Model.Meta):
        anonymous_perms = ["view"]
        authenticated_perms = ["inherit"]
        container_path = "parameters/"
        owner_field = "component__creator"
        owner_perms = ["inherit", "change", "delete"]
        # rdf_context = {
        #     "friendly_name": "sib:friendlyName",
        #     "description": "sib:description",
        #     "component": "sib:component",
        #     "key": "sib:key",
        #     "default": "sib:value",
        # }
        rdf_type = "sib:parameter"
        serializer_fields = ["@id", "friendly_name", "description", "key", "default"]
        superuser_perms = ["inherit"]
        verbose_name = _("parameter")
        verbose_name_plural = _("parameters")


class Package(Model):
    friendly_name = models.CharField(max_length=255, blank=True, null=True)
    short_description = models.CharField(max_length=255, blank=True, null=True)
    creator = models.ForeignKey(
        get_user_model(),
        related_name="packages",
        on_delete=models.SET_NULL,
        null=True,
        blank=True,
    )
    distribution = models.CharField(max_length=255, blank=True, null=True)
    module = models.CharField(max_length=255, blank=True, null=True)
    slug = models.SlugField(unique=True, blank=True, null=True)

    def __str__(self):
        try:
            return "{} ({})".format(self.friendly_name, self.urlid)
        except:
            return self.urlid

    class Meta(Model.Meta):
        anonymous_perms = ["view"]
        authenticated_perms = ["inherit", "add"]
        auto_author = "creator"
        container_path = "/packages/"
        depth = 0
        lookup_field = "slug"
        nested_fields = ["parameters"]
        ordering = ["slug"]
        owner_field = "creator"
        owner_perms = ["inherit", "change", "delete"]
        # rdf_context = {
        #     "friendly_name": "sib:friendlyName",
        #     "short_description": "sib:shortDescription",
        #     "creator": "foaf:user",
        #     "distribution": "sib:distribution",
        #     "module": "sib:module",
        #     "parameters": "ldp:Container",
        # }
        rdf_type = "sib:package"
        serializer_fields = [
            "@id",
            "friendly_name",
            "short_description",
            "creator",
            "distribution",
            "module",
            "parameters",
        ]
        superuser_perms = ["view"]
        verbose_name = _("package")
        verbose_name_plural = _("packages")


class ServerParameter(Model):
    package = models.ForeignKey(
        Package,
        on_delete=models.CASCADE,
        related_name="parameters",
        null=True,
        blank=True,
    )
    friendly_name = models.CharField(max_length=255, blank=True, null=True)
    description = models.CharField(max_length=255, blank=True, null=True)
    key = models.CharField(max_length=255, blank=True, null=True)
    default = models.CharField(max_length=255, blank=True, null=True)

    def __str__(self):
        try:
            return "{} -> {} ({})".format(
                self.package.friendly_name, self.friendly_name, self.urlid
            )
        except:
            return self.urlid

    class Meta(Model.Meta):
        anonymous_perms = ["view"]
        authenticated_perms = ["inherit"]
        container_path = "server-parameters/"
        owner_field = "package__creator"
        owner_perms = ["inherit", "change", "delete"]
        # rdf_context = {
        #     "friendly_name": "sib:friendlyName",
        #     "description": "sib:description",
        #     "package": "sib:package",
        #     "key": "sib:key",
        #     "default": "sib:value",
        # }
        rdf_type = "sib:parameter"
        serializer_fields = ["@id", "friendly_name", "description", "key", "default"]
        superuser_perms = ["inherit"]
        verbose_name = _("server parameter")
        verbose_name_plural = _("server parameters")


@receiver(pre_save, sender=Component)
@receiver(pre_save, sender=Package)
def pre_save_slugify(sender, instance, **kwargs):
    if not instance.urlid or instance.urlid.startswith(settings.SITE_URL):
        if getattr(instance, Model.slug_field(instance)) != slugify(
            instance.friendly_name
        ):
            if (
                sender.objects.local()
                .filter(slug=slugify(instance.friendly_name))
                .count()
                > 0
            ):
                raise ValidationError(sender.__name__ + str(_(" must be unique")))
            setattr(
                instance, Model.slug_field(instance), slugify(instance.friendly_name)
            )
            setattr(instance, "urlid", "")
    else:
        # Is a distant object, generate a random slug
        setattr(instance, Model.slug_field(instance), uuid.uuid4().hex.upper()[0:8])



# Generated by Django 2.2.28 on 2023-05-19 16:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_component', '0002_delete_dependency'),
    ]

    operations = [
        migrations.AddField(
            model_name='component',
            name='auto_menu',
            field=models.BooleanField(default=False, help_text='Enable the experimental menu functionnality, require a solid-***-menu component.'),
        ),
    ]
